=== modified file 'HeaderDateComponent.qml'
--- HeaderDateComponent.qml	2013-09-28 09:37:52 +0000
+++ HeaderDateComponent.qml	2013-10-28 21:08:48 +0000
@@ -26,6 +26,7 @@
 
     Label{
         id: dateLabel
+        objectName: "dateLabel"
         text: date.getDate();
         fontSize: "large"
         horizontalAlignment: Text.AlignHCenter

=== modified file 'WeekView.qml'
--- WeekView.qml	2013-09-28 09:37:52 +0000
+++ WeekView.qml	2013-10-28 21:08:48 +0000
@@ -20,6 +20,7 @@
 
     TimeLineHeader{
         id: weekHeader
+        objectName: "weekHeader"
         type: typeWeek
         date: weekViewPath.weekStart
     }

=== modified file 'calendar.qml'
--- calendar.qml	2013-10-22 17:32:19 +0000
+++ calendar.qml	2013-10-28 21:08:48 +0000
@@ -266,6 +266,7 @@
                     }
                 }
                 Tab{
+                    objectName: "weekTab"
                     title: i18n.tr("Week")
                     page: Page{
                         anchors.fill: parent

=== modified file 'tests/autopilot/calendar_app/emulators.py'
--- tests/autopilot/calendar_app/emulators.py	2013-10-13 18:26:25 +0000
+++ tests/autopilot/calendar_app/emulators.py	2013-10-28 21:08:48 +0000
@@ -28,6 +28,9 @@
     def get_day_view(self):
         return self.select_single("DayView")
 
+    def get_week_view(self):
+        return self.select_single("WeekView")
+
     def get_label_with_text(self, text, root=None):
         if root is None:
             root = self
@@ -85,3 +88,11 @@
         x_stop = view.globalRect[0] + view.globalRect[2] * stop
 
         self.pointing_device.drag(x_start, y_line, x_stop, y_line)
+
+    def get_year(self, component):
+        return int(component.select_single(
+            "Label", objectName="yearLabel").text)
+
+    def get_month_name(self, component):
+        return component.select_single(
+            "Label", objectName="monthLabel").text

=== added file 'tests/autopilot/calendar_app/tests/test_weekview.py'
--- tests/autopilot/calendar_app/tests/test_weekview.py	1970-01-01 00:00:00 +0000
+++ tests/autopilot/calendar_app/tests/test_weekview.py	2013-10-28 21:08:48 +0000
@@ -0,0 +1,98 @@
+# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
+# Copyright 2013 Canonical
+#
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 3, as published
+# by the Free Software Foundation.
+
+"""
+Calendar app autopilot tests for the week view.
+"""
+
+import calendar
+import datetime
+
+from autopilot.matchers import Eventually
+from testtools.matchers import Equals, NotEquals
+
+from calendar_app.tests import CalendarTestCase
+
+
+class TestWeekView(CalendarTestCase):
+
+    def setUp(self):
+        super(TestWeekView, self).setUp()
+        self.assertThat(self.main_view.visible, Eventually(Equals(True)))
+        self.main_view.switch_to_tab("weekTab")
+
+        self.assertThat(
+            self.main_view.get_week_view, Eventually(NotEquals(None)))
+
+        self.week_view = self.main_view.get_week_view()
+
+    def test_current_month_and_year_is_selected(self):
+        """By default, the week view shows the current month and year."""
+
+        now = datetime.datetime.now()
+
+        expected_year = now.year
+        expected_month_name = now.strftime("%B")
+
+        self.assertThat(self.main_view.get_year(self.week_view),
+                        Equals(expected_year))
+
+        self.assertThat(self.main_view.get_month_name(self.week_view),
+                        Equals(expected_month_name))
+
+    def test_current_week_is_selected(self):
+        """By default, the week view shows the current week."""
+
+        now = datetime.datetime.now()
+        days = self.get_days_of_week()
+        monday = (now - datetime.timedelta(days=now.weekday())).day
+        current_month_days = calendar.monthrange(now.year, now.month)[1]
+
+        for i in xrange(7):
+            current_day = int(days[i].text)
+            expected_day = (monday + i) % current_month_days
+
+            if (monday + i) == current_month_days:
+                expected_day = current_month_days
+
+            self.assertThat(current_day, Equals(expected_day))
+
+            color = days[i].color
+            # current day is highlighted in white.
+            if(current_day == now.day):
+                label_color = (color[0], color[1], color[2], color[3])
+                self.assertThat(label_color, Equals((255, 255, 255, 255)))
+
+    def test_show_next_weeks(self):
+        """It must be possible to show next weeks by swiping the view."""
+        self.change_week(1)
+
+    def test_show_previous_weeks(self):
+        """It must be possible to show previous weeks by swiping the view."""
+        self.change_week(-1)
+
+    def change_week(self, direction):
+        now = datetime.datetime.now()
+        current_day_start = (now - datetime.timedelta(days=now.weekday()))
+
+        for i in xrange(1, 5):
+            self.main_view.swipe_view(direction, self.week_view, x_pad=0.15)
+            day_start = datetime.datetime.fromtimestamp(
+                self.week_view.dayStart)
+
+            expected_day_start = current_day_start + datetime.timedelta(
+                days=(i * 7 * direction))
+
+            expected_day_start = expected_day_start.replace(
+                hour=0, minute=0, second=0, microsecond=0)
+
+            self.assertThat(day_start, Equals(expected_day_start))
+
+    def get_days_of_week(self):
+        header = self.main_view.select_single(objectName="weekHeader")
+        timeline = header.select_many("TimeLineHeaderComponent")[1]
+        return timeline.select_many("Label", objectName="dateLabel")

=== modified file 'tests/autopilot/calendar_app/tests/test_yearview.py'
--- tests/autopilot/calendar_app/tests/test_yearview.py	2013-10-22 17:53:04 +0000
+++ tests/autopilot/calendar_app/tests/test_yearview.py	2013-10-28 21:08:48 +0000
@@ -35,8 +35,8 @@
         self.assert_current_year_is_default_one(months[0])
 
         february = months[1]
-        expected_month_name = self.get_month_name(february)
-        expected_year = self.get_year(february)
+        expected_month_name = self.main_view.get_month_name(february)
+        expected_year = self.main_view.get_year(february)
 
         self.pointing_device.click_object(february)
 
@@ -47,8 +47,10 @@
         self.assertThat(month_view.visible, Eventually(Equals(True)))
         selected_month = month_view.select_many("MonthComponent")[1]
 
-        self.assertThat(self.get_year(selected_month), Equals(expected_year))
-        self.assertThat(self.get_month_name(selected_month),
+        self.assertThat(self.main_view.get_year(selected_month),
+                        Equals(expected_year))
+
+        self.assertThat(self.main_view.get_month_name(selected_month),
                         Equals(expected_month_name))
 
     def test_current_day_is_selected(self):
@@ -88,17 +90,9 @@
                 selected_year, Equals(current_year + (i * direction)))
 
     def assert_current_year_is_default_one(self, month_component):
-        self.assertThat(self.get_year(month_component),
+        self.assertThat(self.main_view.get_year(month_component),
                         Equals(datetime.now().year))
 
-    def get_year(self, month_component):
-        return int(month_component.select_single(
-            "Label", objectName="yearLabel").text)
-
-    def get_month_name(self, month_component):
-        return month_component.select_single(
-            "Label", objectName="monthLabel").text
-
     def months_from_selected_year(self):
         # TODO: the component indexed at 1 is the one currently displayed,
         # investigate a way to validate this assumption visually.

